@@ -1,6 +1,7 @@
 <?php
 
 declare(strict_types=1);
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -12,6 +13,7 @@ use OCA\NotifyPush\Queue\IQueue;
 use OCA\NotifyPush\Queue\RedisQueue;
 use OCP\App\IAppManager;
 use OCP\Http\Client\IClientService;
+use OCP\IAppConfig;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use Symfony\Component\Console\Output\OutputInterface;
@@ -23,24 +25,17 @@ class SelfTest {
 
 	private $client;
 	private $cookie;
-	private $config;
-	private $queue;
-	private $connection;
-	private $appManager;
 
 	public function __construct(
 		IClientService $clientService,
-		IConfig $config,
-		IQueue $queue,
-		IDBConnection $connection,
-		IAppManager $appManager,
+		private IConfig $config,
+		private IAppConfig $appConfig,
+		private IQueue $queue,
+		private IDBConnection $connection,
+		private IAppManager $appManager,
 	) {
 		$this->client = $clientService->newClient();
 		$this->cookie = rand(1, (int)pow(2, 30));
-		$this->queue = $queue;
-		$this->config = $config;
-		$this->connection = $connection;
-		$this->appManager = $appManager;
 	}
 
 	public function test(string $server, OutputInterface $output, bool $ignoreProxyError = false): int {
@@ -58,11 +53,11 @@ class SelfTest {
 			return self::ERROR_OTHER;
 		}
 		if (strpos($server, 'localhost') !== false) {
-			$output->writeln('<comment>🗴 push server url is set to localhost, the push server will not be reachable from other machines</comment>');
+			$output->writeln('<comment>🗴 push server URL is set to localhost, the push server will not be reachable from other machines</comment>');
 		}
 
 		$this->queue->push('notify_test_cookie', $this->cookie);
-		$this->config->setAppValue('notify_push', 'cookie', (string)$this->cookie);
+		$this->appConfig->setValueInt('notify_push', 'cookie', $this->cookie);
 
 		try {
 			$retrievedCookie = (int)$this->client->get($server . '/test/cookie', ['nextcloud' => ['allow_local_address' => true], 'verify' => false])->getBody();
@@ -82,19 +77,22 @@ class SelfTest {
 
 		// test if the push server can load storage mappings from the db
 		[$storageId, $count] = $this->getStorageIdForTest();
-		try {
-			$retrievedCount = (int)$this->client->get($server . '/test/mapping/' . $storageId, ['nextcloud' => ['allow_local_address' => true], 'verify' => false])->getBody();
-		} catch (\Exception $e) {
-			$msg = $e->getMessage();
-			$output->writeln("<error>🗴 can't connect to push server: $msg</error>");
-			return self::ERROR_OTHER;
-		}
+		// If no admin user was created during the installation, there are no oc_filecache and oc_mounts entries yet, so this check has to be skipped.
+		if ($storageId !== null) {
+			try {
+				$retrievedCount = (int)$this->client->get($server . '/test/mapping/' . $storageId, ['nextcloud' => ['allow_local_address' => true], 'verify' => false])->getBody();
+			} catch (\Exception $e) {
+				$msg = $e->getMessage();
+				$output->writeln("<error>🗴 can't connect to push server: $msg</error>");
+				return self::ERROR_OTHER;
+			}
 
-		if ((int)$count === $retrievedCount) {
-			$output->writeln('<info>✓ push server can load mount info from database</info>');
-		} else {
-			$output->writeln("<error>🗴 push server can't load mount info from database</error>");
-			return self::ERROR_OTHER;
+			if ((int)$count === $retrievedCount) {
+				$output->writeln('<info>✓ push server can load mount info from database</info>');
+			} else {
+				$output->writeln("<error>🗴 push server can't load mount info from database</error>");
+				return self::ERROR_OTHER;
+			}
 		}
 
 		// test if the push server can reach nextcloud by having it request the cookie
@@ -163,7 +161,7 @@ class SelfTest {
 				$proxies = [$remote, ...array_reverse(array_slice($forwardedParts, 1))];
 				$untrusted = $this->getFirstUntrustedIp($proxies, $trustedProxies);
 				if ($untrusted) {
-					$output->writeln("  <error>$untrusted is not a trusted as a reverse proxy by Nextcloud</error>");
+					$output->writeln("  <error>$untrusted is not trusted as a reverse proxy by Nextcloud</error>");
 					$output->writeln('  See https://docs.nextcloud.com/server/latest/admin_manual/configuration_server/reverse_proxy_configuration.html#defining-trusted-proxies for how to add trusted proxies.');
 				} else {
 					$output->writeln('<info>✓ All proxies in the chain appear to be trusted by Nextcloud</info>');
@@ -194,6 +192,9 @@ class SelfTest {
 			}
 			usleep(10 * 1000);
 			$binaryVersion = $this->queue->getConnection()->get('notify_push_version');
+			if (!$binaryVersion) {
+				throw new \Exception('push server didn\'t set expected redis key');
+			}
 		} catch (\Exception $e) {
 			$msg = $e->getMessage();
 			$output->writeln("<error>🗴 failed to get binary version: $msg</error>");
@@ -234,7 +235,7 @@ class SelfTest {
 			->groupBy('storage_id')
 			->setMaxResults(1);
 
-		return $query->execute()->fetch(\PDO::FETCH_NUM);
+		return $query->executeQuery()->fetch(\PDO::FETCH_NUM);
 	}
 
 	private function isValidProxyConfig(string $proxyConfig): bool {
